==> huaweicloudsdkcfw-3.1.124-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/batch_delete_acl_rules_response_data.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteAclRulesResponseData:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'response_datas': 'list[BatchDeleteRuleInfo]'
    }

    attribute_map = {
        'response_datas': 'responseDatas'
    }

    def __init__(self, response_datas=None):
        """BatchDeleteAclRulesResponseData

        The model defined in huaweicloud sdk

        :param response_datas: 批量删除规则返回data
        :type response_datas: list[:class:`huaweicloudsdkcfw.v1.BatchDeleteRuleInfo`]
        """
        
        

        self._response_datas = None
        self.discriminator = None

        if response_datas is not None:
            self.response_datas = response_datas

    @property
    def response_datas(self):
        """Gets the response_datas of this BatchDeleteAclRulesResponseData.

        批量删除规则返回data

        :return: The response_datas of this BatchDeleteAclRulesResponseData.
        :rtype: list[:class:`huaweicloudsdkcfw.v1.BatchDeleteRuleInfo`]
        """
        return self._response_datas

    @response_datas.setter
    def response_datas(self, response_datas):
        """Sets the response_datas of this BatchDeleteAclRulesResponseData.

        批量删除规则返回data

        :param response_datas: The response_datas of this BatchDeleteAclRulesResponseData.
        :type response_datas: list[:class:`huaweicloudsdkcfw.v1.BatchDeleteRuleInfo`]
        """
        self._response_datas = response_datas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteAclRulesResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcfw-3.1.149-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/batch_delete_acl_rules_response_data.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteAclRulesResponseData:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'response_datas': 'list[BatchDeleteRuleInfo]'
    }

    attribute_map = {
        'response_datas': 'responseDatas'
    }

    def __init__(self, response_datas=None):
        r"""BatchDeleteAclRulesResponseData

        The model defined in huaweicloud sdk

        :param response_datas: 批量删除规则返回data
        :type response_datas: list[:class:`huaweicloudsdkcfw.v1.BatchDeleteRuleInfo`]
        """
        
        

        self._response_datas = None
        self.discriminator = None

        if response_datas is not None:
            self.response_datas = response_datas

    @property
    def response_datas(self):
        r"""Gets the response_datas of this BatchDeleteAclRulesResponseData.

        批量删除规则返回data

        :return: The response_datas of this BatchDeleteAclRulesResponseData.
        :rtype: list[:class:`huaweicloudsdkcfw.v1.BatchDeleteRuleInfo`]
        """
        return self._response_datas

    @response_datas.setter
    def response_datas(self, response_datas):
        r"""Sets the response_datas of this BatchDeleteAclRulesResponseData.

        批量删除规则返回data

        :param response_datas: The response_datas of this BatchDeleteAclRulesResponseData.
        :type response_datas: list[:class:`huaweicloudsdkcfw.v1.BatchDeleteRuleInfo`]
        """
        self._response_datas = response_datas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteAclRulesResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
